@@ -11,9 +11,11 @@ from mcdbot.config import Config, default_config_obj
 from mcdbot.mcdbot import Mcdbot
 import json
 import sys
+from loguru import logger
 
 
 if __name__ == '__main__':
+    logger.info("Starting up...")
     path = 'mcdbot_config.json'
     try:
         path = sys.argv[1]
@@ -24,6 +26,6 @@ if __name__ == '__main__':
         config = Config(**json.load(open(path, 'r')))
     except FileNotFoundError:
         json.dump(default_config_obj, open(path, 'w'))
-        config = Config(**json.load(open(path, 'r')))
+        raise RuntimeError("Please configure me in the newly created file.")
 
     Mcdbot(config).run()
